@@ -26,7 +26,7 @@ class Loc(object):
     """Source location
 
     """
-    _defmatcher = re.compile(r'def\s+(\w+)\(.*')
+    _defmatcher = re.compile(r'def\s+(\w+)')
 
     def __init__(self, filename, line, col=None, maybe_decorator=False):
         """ Arguments:
@@ -82,10 +82,11 @@ class Loc(object):
     def _raw_function_name(self):
         defn = self._find_definition()
         if defn:
-            return self._defmatcher.match(defn.strip()).groups()[0]
-        else:
-            # Probably exec(<string>) or REPL.
-            return None
+            m = self._defmatcher.match(defn.strip())
+            if m:
+                return m.groups()[0]
+        # Probably exec(<string>) or REPL.
+        return None
 
     def get_lines(self):
         if self.lines is None:
@@ -562,6 +563,15 @@ class Expr(Inst):
         op = 'null'
         return cls(op=op, loc=loc)
 
+    @classmethod
+    def undef(cls, loc):
+        """
+        A node for undefined value specifically from LOAD_FAST_AND_CLEAR opcode.
+        """
+        assert isinstance(loc, Loc)
+        op = 'undef'
+        return cls(op=op, loc=loc)
+
     @classmethod
     def dummy(cls, op, info, loc):
         """
@@ -1128,6 +1138,11 @@ class Var(EqualityCheckMixin, AbstractRHS):
         """
         return self.versioned_names | {self.unversioned_name,}
 
+    def __deepcopy__(self, memo):
+        out = Var(copy.deepcopy(self.scope, memo), self.name, self.loc)
+        memo[id(self)] = out
+        return out
+
 
 class Scope(EqualityCheckMixin):
     """
